@@ -11,23 +11,25 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"10.2.44-MariaDB"
-#define MYSQL_BASE_VERSION		"mysqld-10.2"
-#define MARIADB_BASE_VERSION		"mariadb-10.2"
+#define MYSQL_SERVER_VERSION		"10.5.13-MariaDB"
+#define MYSQL_BASE_VERSION		"mysqld-10.5"
+#define MARIADB_BASE_VERSION		"mariadb-10.5"
+#define MARIADBD_BASE_VERSION		"mariadbd-10.5"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		100244
+#define MYSQL_VERSION_ID		100513
 #define MARIADB_PORT                    3306
 #define MYSQL_PORT_DEFAULT		0
 #define MARIADB_UNIX_ADDR               "/tmp/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
 #define MYSQL_COMPILATION_COMMENT	"MariaDB Server"
+#define SERVER_MATURITY_LEVEL           MariaDB_PLUGIN_MATURITY_STABLE
 
 #define MYSQL_PORT                      MARIADB_PORT
 #define MYSQL_UNIX_ADDR                 MARIADB_UNIX_ADDR
 
 #ifdef WITH_WSREP
-#define WSREP_PATCH_VERSION             "wsrep_25.24"
+#define WSREP_PATCH_VERSION             "wsrep_26.22"
 #endif
 
 /* mysqld compile time options */
